package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````]!4``#0````<L0```````#0`(``,
M`"@`&0`8``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!<````7````!`````$````!````````````````````T`\`
M`-`/```$`````!````$`````$````!`````0``#?,P``WS,```4`````$```
M`0````!0````4````%```#Q.```\3@``!``````0```!````X*T``."M``#@
MK0``-`(``&`"```&`````!````(```#HK0``Z*T``.BM``#P````\`````8`
M```$````!````,P!``#,`0``S`$``$P```!,````!`````0```!3Y71D\`$`
M`/`!``#P`0``*````"@````$````!````%#E=&1PD```<)```'"0```4`0``
M%`$```0````$````4>5T9```````````````````````````!@```!````!2
MY71DX*T``."M``#@K0``(`(``"`"```$`````0```"]L:6(O;&0M;75S;"UI
M,S@V+G-O+C$```0````4`````P```$=.50`]"KR$314,;Y`<]/HVUG9!K;0C
M8@0````8````!0```$=.50`!``'`!`````D````"``'`!`````$````1````
M2`````@````(`````!`0`"5`!(`H`!`$H(8`A("!``(+(`0).(`208H$"`@`
M````2````$P```!0````40```%@```!9````6@````````!<````70``````
M``!>````7P```&$``````````````.K3[PYNQ=\?:G^:?,_>1RT@_^0.+L6;
MMM1DU'RYC?$.V7%8'/JA;&#"Y3\L0OK7AYA/PYNR`8MONN.2?.-'Q@%5PSS2
M9Z_,9D)%U>R)!W#3,V+;[16,)<Q_J9R;X*<""FL:GE"CX/M)````````````
M`````````)@"`````````````!$``````@`````````````2````;P$`````
M````````$@```+$!`````````````!(```!3```````````````2````;P(`
M````````````$@```.T"`````````````"$```"-`@`````````````2````
M$```````````````$@```$L``````````````!(```!;```````````````2
M````*```````````````$@```)P``````````````"`````8`0``````````
M```2````/0(`````````````$@```&$!`````````````!(```!Z`@``````
M```````2````E0``````````````$@```!@``````````````!(```"B`0``
M```````````2````K@(`````````````$@```"X``````````````!(```"1
M`0`````````````2````4P$`````````````$@```#P``````````````!(`
M``!:`0`````````````2````C0``````````````$@````$`````````````
M`!(```#Q```````````````2````+0(`````````````$@```.\"````````
M`````"$```"Z```````````````2````\`(`````````````$0```/L!````
M`````````!(```"]`0`````````````2````)@$`````````````$@```#T!
M`````````````!(````?```````````````2````0P``````````````$@``
M`#<!`````````````!(````2`0`````````````2````!@0`````````````
M$@```/8``````````````"````"%```````````````2````[@(`````````
M````$0```$8"`````````````!(```"G`@`````````````2````PP``````
M````````(@```(```````````````!(```!?`@`````````````2````Y0$`
M````````````$@```/@"`````````````!(```!1`@`````````````2````
MA@(`````````````$@```+T"`````````````!(````)```````````````1
M````C```````````````$@```-@!`````````````!$````,`@``````````
M```2````9```````````````(````#4``````````````!(```#;`@``````
M```````2````M@(`````````````$@```,0"`````````````!(```#V`0``
M```````````2````UP``````````````(````-(``````````````!(```!^
M`0`````````````6````TP(`````````````$@```$P!`````````````!(`
M```?`@`````````````2````T@$``-A#```!````$@`-`+@#``"`,@``T```
M`!(`#`#H`@``P!,``#0"```2``P`%`0``&`I``#P!@``$@`,`$\#``"@'@``
M-0(``!(`#`#$`P``D!X```4````2``P`(00``%`P```E`@``$@`,`)0#````
M$````0```!(`"0!Z`P``%+`````````0`!8`/0,``'`H``#P````$@`,`&8#
M```P'0``-@```!(`#`"&`P``L#\```8"```2``P`F@,``(`F```T````$@`,
M`-P#```0)@``80```!(`#``/!```0+`````````0`!8`-P0``.`@```R````
M$@`,`*(#```/%@``-P```!(`#`!N`P``("$``.D````2``P`U0,``!2P````
M````$``5`.H#```0L```!````!$`%0!_`P``]!4````````0``P`D0,``&`_
M``!!````$@`,`/0#``!`*```*P```!(`#``G`P``<!T``!D!```2``P`7`,`
M`,!!``#_`0``$@`,`*L#```0(@``_`,``!(`#```;W!E;F1I<@!S=&1E<G(`
M<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`;'-E96L`9V5T<&ED`'-T<F-M<`!U
M;FQI;FL`;65M;6]V90!S=')N8VUP`'-T<G)C:'(`8VQO<V5D:7(`7TE435]D
M97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'9F<')I;G1F`'-T
M<F-H<@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;U]B87-E<P!R96%D;&EN:P!?
M7V-X85]F:6YA;&EZ90!E>&ET`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`
M<F5A9`!?7W)E9VES=&5R7V9R86UE7VEN9F]?8F%S97,`<FUD:7(`7U]S=&%T
M7W1I;64V-`!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER`%]?;'-T871?=&EM938T
M`&UE;6-P>0!S=')L96X`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?
M:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R
M;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`
M7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E
M`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V
M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S
M=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES
M;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``<W1R8W!Y`')E861D
M:7(`<W1R=&]K`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!S<')I;G1F`%]?;&EB
M8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`7U]S=&%C:U]C:&M?9F%I;`!L:6)P
M97)L+G-O`&QI8F,N;75S;"UX.#8N<V\N,0!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`'-H85]F:6YA;`!X
M<U]I;FET`'!A<E]D:7)N86UE`%]?8G-S7W-T87)T`'-H85]U<&1A=&4`<VAA
M7VEN:70`<&%R7V1I90!?<W1A<G1?8P!P87)?:6YI=%]E;G8`<&%R7V-L96%N
M=7``<&%R7V-U<G)E;G1?97AE8P!?961A=&$`<&%R7V5N=E]C;&5A;@!M>5]P
M87)?<&P`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`7V5N9`!P87)?;6MT
M;7!D:7(`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]B87-E;F%M90`O=7-R
M+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210```."M```(````Y*T```@```#$
MKP``"````/"O```(````_*\```@`````L```"````!"P```(````P*\```8!
M``#(KP``!@T``,RO```&%P``T*\```8A``#4KP``!BL``-BO```&,```W*\`
M``8R``#@KP``!C@``.2O```&.@``Z*\```8[``#LKP``!CP``/2O```&0@``
M^*\```Y$``#DK@``!P(``.BN```'`P``[*X```<$``#PK@``!P4``/2N```'
M!@``^*X```<(``#\K@``!PD```"O```'"@``!*\```<+```(KP``!PP```RO
M```'#@``$*\```</```4KP``!Q```!BO```'$0``'*\```<2```@KP``!Q,`
M`"2O```'%```**\```<5```LKP``!Q8``#"O```'&```-*\```<9```XKP``
M!QH``#RO```'&P``0*\```<<``!$KP``!QT``$BO```''@``3*\```<@``!0
MKP``!R(``%2O```'(P``6*\```<D``!<KP``!R4``&"O```')@``9*\```<G
M``!HKP``!R@``&RO```'*0``<*\```<J``!TKP``!RP``'BO```'+@``?*\`
M``<O``"`KP``!S$``(2O```',P``B*\```<T``",KP``!S4``)"O```'-@``
ME*\```<W``"8KP``!SD``)RO```'/0``H*\```<^``"DKP``!S\``*BO```'
M0```K*\```=!``"PKP``!T,``+2O```'10``N*\```=&``"\KP``!T<`````
M````````````````````````````````````````````````````````````
M`(/L#(/$#,,```````````#_LP0```#_HP@`````````_Z,,````:`````#I
MX/____^C$````&@(````Z=#_____HQ0```!H$````.G`_____Z,8````:!@`
M``#IL/____^C'````&@@````Z:#_____HR````!H*````.F0_____Z,D````
M:#````#I@/____^C*````&@X````Z7#_____HRP```!H0````.E@_____Z,P
M````:$@```#I4/____^C-````&A0````Z4#_____HS@```!H6````.DP____
M_Z,\````:&````#I(/____^C0````&AH````Z1#_____HT0```!H<````.D`
M_____Z-(````:'@```#I\/[___^C3````&B`````Z>#^____HU````!HB```
M`.G0_O___Z-4````:)````#IP/[___^C6````&B8````Z;#^____HUP```!H
MH````.F@_O___Z-@````:*@```#ID/[___^C9````&BP````Z8#^____HV@`
M``!HN````.EP_O___Z-L````:,````#I8/[___^C<````&C(````Z5#^____
MHW0```!HT````.E`_O___Z-X````:-@```#I,/[___^C?````&C@````Z2#^
M____HX````!HZ````.D0_O___Z.$````:/````#I`/[___^CB````&CX````
MZ?#]____HXP```!H``$``.G@_?___Z.0````:`@!``#IT/W___^CE````&@0
M`0``Z<#]____HY@```!H&`$``.FP_?___Z.<````:"`!``#IH/W___^CH```
M`&@H`0``Z9#]____HZ0```!H,`$``.F`_?___Z.H````:#@!``#I</W___^C
MK````&A``0``Z6#]____H[````!H2`$``.E0_?___Z.T````:%`!``#I0/W_
M__^CN````&A8`0``Z3#]____H[P```!H8`$``.D@_?___Z/`````:&@!``#I
M$/W___^CQ````&AP`0``Z0#]____H\@```!H>`$``.GP_/___Z/,````:(`!
M``#IX/S___^CT````&B(`0``Z=#\____H]0```!HD`$``.G`_/___Z/8````
M:)@!``#IL/S___^CW````&B@`0``Z:#\____H^````!HJ`$``.F0_/___Z/D
M````:+`!``#I@/S___^C\````&:0_Z/\````9I#_HP`!``!FD```````````
M#PL/"P\+9I!FD&:09I!FD(U,)`2#Y/#_<?Q5B>57B<]64^AO`@``@<,!FP``
M48/L+(M!!(E%U(M!"(E%T&6A%````(E%Y#'`C4704(U%U%!1Z"K\__^+@Q`!
M``"#Q`Q04/^S]````.@4____BX,,`0``@\00@#@`#X07`0``BX,@`0``98L`
M@(C2`@```XL'C7`#@\`$B77,/?___S\/AW,!``"#[`S!X`)0Z)#\__^+==2+
M/X/$$(G!B8-@`0``BP:)`8V#`*/__XE!!(N#.`$``(E!"(V#`Z/__XE!#(/_
M`0^.0P$``(E-R(U&!(U1$(TTOHUT)@"+"(/`!(/"!(E*_#G&=?&+3<B#QP.#
M[`R-@_AM___'!+D`````:@!1_W7,4/^S9`$``.B!^___@\0@A<`/A(\```"#
M[`S_LV0!``"-?>#HQ?W__XGZB<:-@[RA___HE@(``(/$$(7`='Z#[`S_LV0!
M``#H(?[__^B\^___@\00BT7D92L%%`````^%N````(UE\(GP65M>7UV-8?S#
MZ";[__^)@V0!``"%P`^$C0```(/L#%#HO_O__XN#(`$``(/$$&6+$,:"I@4`
M``#IN_[__X/L#/^S9`$``.A)^___@\00Z5O___^+@UP!``"%P'01@^P,4.C>
M'```@\00Z6?___^)^HV#<:'__^CI`0``B8-<`0``A<`/A$S____KTE!0C8-L
MH?___[/H````4.@%_/__OP0```#IV/[__X/L#&H!Z&']___HRRT``#'MB>"#
MY/!04.@`````@00DYI<``%#H`````%/H,0```('#PY@``(/L$(M$)!AJ`(U0
M!/^S[````/^S)`$``%+_,/^S&`$``.C/_/__@\0H6\.+'"3#9I!FD&:0Z$4!
M``"!PH.8``"-BCP!``"-@CP!```YR'0=BX(4`0``A<!T$U6)Y8/L%%'_T(/$
M$,G#C70F`)##C;0F`````.@%`0``@<)#F```58GE4XV*/`$``(V"/`$``(/L
M!"G(B</!Z!_!^P(!V-'X=!2+DAP!``"%TG0*@^P(4%'_TH/$$(M=_,G#C;0F
M`````&:058GE4^A=____@</OEP``@^P$@+L\`0```'5#BY,``0``A=)T$8/L
M#/^S*`$``.B-_/__@\00Z#7___^+@_````"%P'02@^P,C8/\XO__4.A<_/__
M@\00QH,\`0```8M=_,G#C;0F`````(VV`````%7H`````%J!PH*7``")Y5/H
MX?[__X'#<Y<``(/L!(N#_````(7`=!F-@T`!``!2:@!0C8/\XO__4.@*_/__
M@\00BUW\R>GV_O__BQ0DPV:055=64^B=_O__@<,OEP``@^P<B50D"(7`#X2R
M````B<&+@_@```"+$(72#X2@````#[8!A,!T!#P]=54Q[8LRA?9T/(E4)`R)
M\(G6B4PD!(G'C;0F`````(/L!%7_="0,5^B*^/__@\00A<!U!H`\+SUT-8M^
M!(/&!(7_==N)_H/$'(GP6UY?7<.-M"8`````B<T/MD4!@\4!A,!T!#P]=?$I
MS>N8C78`BU0D#(GXB?>)QHM$)`@IUXUT+@'!_P*).(/$'(GP6UY?7<.-="8`
MD(/$'#'V6XGP7E]=PXUT)@!6B<93Z+W]__^!PT^6``"![*P```!EH10```")
MA"2D````,<"-1"044%;H4?G__X/$$(7`=3J+5"0<@>(`\```@?H`0```=`B!
M^@"@``!U(H/L"&H"5N@U^/__@\00A<`/E,`/ML#K"HVT)@````"0,<"+E"2<
M````92L5%````'4)@<2D````6U[#Z*\J``!55U:)QE/H*_W__X'#O94``('L
MO````&6A%````(F$)*P````QP(7V=`6`/@!U(8N$)*P```!E*P44````#X4N
M`0``@<2\````6UY?7<-FD(/L#%;H)_C__X/$$(G'A<!TS8/L#%?HM??__X/$
M$(7`#X2R````@'@3+HU0$W4)@'H!`'3=C78`@'@3+@^$M@```(E4)`R#[`Q6
MZ*'W__^+5"0<B<6)%"2)5"0<Z(_W__^-1`4"B00DZ`/Y__^+5"0<B<6-@RBA
M__]25E!5Z'[Y__^#Q!B-1"0D4%7HT/;__X/$$(/X_W00BT0D+"4`\```/0!`
M``!T<(/L#%7H3_?__X/$$(/L#%7HL_?__X/$$(/L#%?H!_?__X/$$(7`#X52
M____C70F`(/L#%?H7_;__XDT).CW]___@\00Z>[^__^-M"8`````@'H!+@^%
M0/___X!Z`@`/A`;____I,?___XVT)@````")Z.B1_O__ZY/H.2D``(VT)@``
M``"-=@!5B<575HG64^BI^___@<,[E```@^PX9:$4````B40D*#'`,<"`.CT/
ME,`!QE;HCO;__X/$$(E$)`2-5"08B>CHS/S__X7`#X0$`0``@^P,B<=0Z&GV
M__^+3"04@\00.<@/@\H```"+1"08P>`"B40D"(N#^````(D$)`^V10"$P`^$
MF@$``#P]#X22`0``B>@/ME`!@\`!A-)T!8#Z/77P*>B+#"2+?"0(@^P,BU0D
M$`,YC400`E#HA/?__X/$$(D'A<!T2HL,)(M\)`B+`8U-`8L4.`^V10"(`CP]
M=1'K$P^V`8/"`8/!`8@"/#UT!(3`=>W&`CTQP(VT)@````"0#[8,!HA,`@&#
MP`&$R77QBT0D'&4K!10````/A1,!``"#Q"Q;7E]=PXVT)@````"0,<"-M@``
M```/MA0&B!0'@\`!A-)U\NO'C;0F`````)"+@_@```"+$(D$)(LZA?\/A,(`
M```Q_XVT)@````!FD(GX@\<!BPRZA<EU](T$A0P```"+BU@!``"%R75CB50D
M#(/L#%#'@U@!```!````Z)SV__^#Q!")P87`#X1>____C02]`````(/L!(E$
M)`Q0BU0D%%)1B4PD'.C!]?__BT0D$(M,)!R#Q!")",=$N00`````B7PD&.F-
M_O__C78`@^P(4%+H]O/__XG!BT0D$(/$$(D(A<D/A`+___^-!+T`````B40D
M".O"C;8`````,<#I>_[__[@(````,?_I4/___^CW)@``C;0F`````)!64^AO
M^?__@<,!D@``@^P$C8-XX?__B[,@`0``4(V#+J'___^S!`$``%!E_S;H;O7_
M_UB-@]VB__]::@!04(V#>('__U"-@TJA__]09?\VZ'SU__^#Q"1;7L.-M@``
M``!3Z!#Y__^!PZ*1``"#[`B-@WCA__]0C8,NH?___[,$`0``4(N#(`$``&7_
M,.@/]?__@\086\.-M"8`````C78`55=64X'L`!```(,,)`"![``0``"##"0`
M@^P<Z+;X__^!PTB1``!EH10```")A"0,(```,<#HEO/__X/L#(V37Z'__U)0
MC8-CH?__4&@!$```C70D)E;H1?3__X/$((U0`8'Z`1````^'T_7__X/X_P^$
MF@```(/L!&@`$```C;PD$Q```%=6Z,3S__^#Q!")Q87`>'N#[`R-0`%0Z+_T
M__^#Q!")QH7`=&8Y^',+C00H.<</@H?U__\Y]W)#@?T!$```#X=W]?__@^P$
M55=6Z"SU___&!"X`@\00BX0D#"```&4K!10```!U*8'$'"```(GP6UY?7<.-
MM"8`````D(T$+SG&<[;I-/7__XUT)@`Q]NO'Z#8E``"-M"8`````Z=O^__^-
MM"8`````C70F`%575E.![``0``"##"0`@>S,````Z(WW__^!PQ^0``"+O"3@
M$```BZPDY!```&6A%````(F$)+P0```QP(U$)"R)1"04B<*-@W&A___HK_C_
M_X/L"&HOB<97Z`+R__^#Q!"%P'0SC8-ZH?__B?KH?OO__XGXBY0DO!```&4K
M%10````/A:@!``"!Q,P0``!;7E]=PXUT)@"0@^P,5>B?\___6EF-BX>A__^)
M3"0445#HS//__X/$$(V+B:'__XG%C8.2HO__B40D&(7M=)B`?0``B4PD'`^$
M]@```(UT)@"0A?9T%8/L"%56Z'+S__^#Q!"%P`^$LP```(/L#%7HKO'__X/$
M$(G"C40%_SG%<A/K)(VT)@````#&``"#Z`$YQ70%@#@O=/&#[`Q5Z(#Q__^#
MQ!")PHE4)!"#[`Q7Z&[Q__^+5"0@@\00C40"`3W_#P``#X<-____@^P(5_]T
M)"A5_W0D+&@`$```C:PDV````%7H^?'__X/$((/``3T`$```#X>*\___@^P(
M_W0D'%7HB_#__X/$$(7`=1"+1"0\)0#P```]`(```'14@^P(_W0D%&H`Z,;R
M__^#Q!")Q87`#X2>_O__@'T```^%#____X7V=`6`/BYT%KH!````C:MOH?__
MZ4O___^-M@````"`?@$`=+;KXHVT)@````"0@^P(:@%5Z&7P__^#Q!"%P'6:
MB>J-@WJA___HT?G__X/L#%7H&/+__X/$$.E$_O__Z.HB``"-M"8`````C70F
M`%93Z%_U__^!P_&-``"#[`R+="08:B]6Z%3O__^%P(U0`0]%\HDT).C4\?__
M@\046U[#C;0F`````(VT)@````!64X'L`!```(,,)`"#[!3H$O7__X'#I(T`
M`(NT)"`0``!EH10```")A"0,$```,<"%]@^$F````(`^``^$CP```(/L#%;H
MYN___X/$$(U0`3'`@?H`$```=UJ#[`A6C70D&%;H^/#__XDT).C`[___@\00
MC40&_SG&<@_K$HUV`,8``(/H`3GP=`6`."]T\8/L"&HO5NB6[O__@\00A<!T
M+SG&<P/&``"#[`Q6Z`_Q__^#Q!"+E"0,$```92L5%````'4@@<04$```6U[#
MC78`@^P,C8-OH?__4.CA\/__@\00Z]#HMB$``(VT)@````!55U;H/!$``('&
MP(P``%.#["QEH10```")1"0<,<"-7"08BZ[X````C;Z+H?__B=J)^.A9]?__
MA<!T+HM4)!B+10"-!)"+4`2)$(72=.!FD(M0"(/`!(D0A=)U](G:B?CH*_7_
M_X7`==*+KO@```"-OI2A__^)VHGXZ!+U__^%P'0OBU0D&(M%`(T$D(M0!(D0
MA=)TX(UV`(M0"(/`!(D0A=)U](G:B?CHX_3__X7`==&+KO@```"-OIRA__^)
MVHGXZ,KT__^%P'0OBU0D&(M%`(T$D(M0!(D0A=)TX(UV`(M0"(/`!(D0A=)U
M](G:B?CHF_3__X7`==&+KO@```"-OJ6A__^)VHGXZ(+T__^%P'0OBU0D&(M%
M`(T$D(M0!(D0A=)TX(UV`(M0"(/`!(D0A=)U](G:B?CH4_3__X7`==&-AJRA
M__^+OO@```")!"2+!"2)VN@V]/__A<!T+(M4)!B+!XT$D(M0!(D0A=)TX(M0
M"(/`!(D0A=)U](L$)(G:Z`KT__^%P'74BZ[X````C;Z\H?__B=J)^.CQ\___
MA<!T-HM4)!B+10"-!)"+4`2)$(72=."-M"8`````C78`BU`(@\`$B1"%TG7T
MB=J)^.B[\___A<!URHV&<:'__XN^^````(E$)`2+1"0$B=KHG//__X7`=#.+
M5"08BP>-!)"+4`2)$(72=-^-M@````"+4`B#P`2)$(72=?2+1"0$B=KH:?/_
M_X7`=<V-ALBA__^+OO@```")1"0,BT0D#(G:Z$KS__^%P'0QBU0D&(L'C020
MBU`$B1"%TG3?C70F`(M0"(/`!(D0A=)U](M$)`R)VN@9\___A<!USXV&TJ'_
M_XN^^````(E$)`B+1"0(B=KH^O+__X7`=#&+5"08BP>-!)"+4`2)$(72=-^-
M="8`BU`(@\`$B1"%TG7TBT0D"(G:Z,GR__^%P'7/BZ[X````C;[<H?__B=J)
M^.BP\O__A<!T-8M4)!B+10"-!)"+4`2)$(72=."-M"8`````9I"+4`B#P`2)
M$(72=?2)VHGXZ'OR__^%P'7+BZ[X````C;YZH?__B=J)^.AB\O__A<!T+XM4
M)!B+10"-!)"+4`2)$(72=."-=@"+4`B#P`2)$(72=?2)VHGXZ#/R__^%P'71
MB=J-AN:A___H(O+__X7`=`N)PHM$)`CH`_7__XG:C8;WH?__Z`;R__^%P'0-
MB<*-A@FB___HY?3__XG:C884HO__Z.CQ__^)PH7`="N+1"0$Z,GT__^+1"0<
M92L%%````'4SBP0D@\0LC98UHO__6UY?7>FG]/__B=J-AB2B___HJO'__X7`
M=,V)PHM$)`SHB_3__^O`Z+,=``"-="8`Z#L-```%PX@``(/L'&6+%10```")
M5"0,,=*-5"0(C8#(H?__Z&?Q__^%P'0K#[80@/HP#Y3`A-(/E,()T(/P`0^V
MP(M4)`QE*Q44````=0R#Q!S#C70F`#'`Z^?H3AT``(VT)@````"-M"8`````
MD%/HP.___X'#4H@``(/L"(U$)!2#[`10_W0D&(N#"`$``/\PZ$CL___'!"3_
M````Z)SL__^-M"8`````C70F`)!55U93C9PD``#__X'L`!```(,,)``YW'7R
M@^PLZ&7O__^!P_>'``")Q66A%````(F$)!P``0`QP&H":@!J`%7HK.G__X/`
M_X/2_XE$)!B+="08B=>)5"0<P?\?,?@I^#'2)?__```Q^C'X*?@9^HM\)!PI
MQHET)!@9UXE\)!R#Q!"-="04A?\/B+L```"-=@!J`/]T)!#_="005>A0Z?__
M@\00(="#^/\/A+4```"#[`1H"``!`%95Z"/J__^#Q!"#^/\/A(L```"#^`=V
M4HU$!O@Y\')*C3TL`0``ZPEFD(/H`3GP<CF+$(M(!#,4'S-,'P0)RG7I*?"9
M`T0D"!-4)`R+C"0<``$`92L-%````'5@@<0L``$`6UY?7<.-=@"!1"0(``#_
M_XM4)`B#5"0,_XM,)`R)T(G*-0``___WT@G0#X5(____N/____^Z_____^NN
M@^P,C8-$HO__4.A=_O__@^P,C8,WHO__4.A._O__Z(@;``"-M"8`````9I!3
MZ`#N__^!PY*&``"#[`CH'.G__X/L#%#H\^G__X/$$(7`=`*+`(/$"%O#C70F
M`)!55U93Z,WM__^!PU^&``"#["QEH10```")1"0<,<"-5"08BVPD0(V[4*+_
M_XGXZ/WN__^%P'0'@#@`B<9U(HM$)!QE*P44````#X6<````B>J#Q"R)^%M>
M7UWIP?'__Y"#[`A54.B&Z?__@\00A<!T'XM$)!QE*P44````=6V#Q"Q;7E]=
MPXVT)@````"-=@"#[`Q5Z$?H__^)-"2)1"0<Z#OH__^+5"0<C40"`HD$).BK
MZ?__B30DB<*-@X>A__]0C8.2HO__55!2B50D+.@=ZO__@\0@BU0D#(M$)!QE
M*P44````#X1F____Z%\:``!55U93Z-WL__^!PV^%``"!["P!``"+A"1``0``
MC7PD((GZB40D#(V+9Z+__V8/;L&-BQ^B__]EH10```")A"0<`0``,<"-@V^A
M__]F#V[)C8L"HO__QX0DN`````````!F#V[0C8-THO__9@]BPF8/;MB-@VRB
M___'A"3D`````````&8/;N!F#V++9@_6A"2P````9@]NP68/8L2-@WVB__^-
MBWBB___'A"3(`````````&8/;,%F#V[HC8-QH?__#Q&$)-0```!F#V[!9@]B
MQ8E$)!AF#]:$),````#H7>W__X7`=`F`.``/A5@$``#H&^?__X/L#%#H\N?_
M_X/$$(7`#X0'`@``BRB%[0^$_0$``(/L#%7HU.;__X/$$(/L#(U$``%0Z$3H
M__^#Q!")Q@^V10")="0(A,!T-8V+AJ+__XE\)`2)[XGUB<Z-=@"#[`0/ML"#
MQP%05E6#Q0+HG.C__P^V!X/$$(3`=>*+?"0$C;0DT````(V#":+__^L1C;0F
M`````(M&!(/&!(7`="Z)^NBG[/__B<6%P'3I@#@`=.3H=^W__X7`=-N#[`Q5
MZ,KG__^#Q!")Q87`=3&0C;0DL````(LNA>UT(X!]```/A"D!``")Z.A"[?__
MA<`/A?H```"+;@2#Q@2%[77=@^P,5>CWY?__6O]T)!2)QNCKY?__C;0&!`0`
M`(DT).A<Y___B40D%(G!6(V#BZ+__UK_="004(V#B:'__XE$)!A0C8.0HO__
M58G-4%'HON?__X/$&&C``0``5>B`YO__@\00@_C_=1#H,^;__XL`@_@1#X6R
M`@``@^P(5_]T)!#H*^;__X/$$(G%A<!U%(M$)#`E`/```#T`0```#X3M````
M_W0D!(M$)!#_,(V#1*/__U"+@P@!``#_,.APY?__@\00,?:+A"0<`0``92L%
M%`````^%$P0``('$+`$``(GP6UY?7<.-M"8`````C78`@^P,@\8$5>B4YO__
M@\00B<6%P`^$SO[__^GR_O__9I`Q[>GI_O__C;0F`````&:0BX0DP````(VT
M),````"%P'0@C;8`````B?KH$>O__X7`=`6`.`!U,(M&!(/&!(7`=>:#[`R-
MJV"B__]J#>@>YO__@\00B<:)1"0(N%,```#IV/W__XUV`(/L#%#H#^;__X/$
M$(G%A<!TONF4_?__BT0D.(E$)!#HA.3__SE$)!`/A?S^__^+1"0P)?\!```]
MP`$```^%Z/[__X/L#%;HO>7__XGZB<:-@UNB___H?NK__X/$$(7`#X2C`0``
M@^P(4(M$)!C_,.AD\?__B40D((/$$(7`#X2%`0``@^P,_W0D'.CYX___@\00
MB<*#^`-V/X/L"(V#F:+__U"+1"0<C400_(E4)"A0Z(/E__^#Q!"%P'4<BU0D
M'(/Z!`^$5`(``(M$)!"`?!#[+P^$10(``(GZC;O(H?__B?CH\>G__X7`#X0I
M`0``#[8`A,`/A!X!```\,`^$%@$``(V3-:+__XGXC;O=HO__Z+/L___H7N/_
M_X/L"%=0C8.]HO___W0D&/]T)!A05NADY?__@\0@C8/+HO__B40D#.LRC70F
M`)#HV^/__X,X$74YZ"'C__^#Q0&#[`1755#_="08_W0D&/]T)"16Z";E__^#
MQ""#[`AHP`$``%;HY>/__X/$$(/X_W2]@^P,_W0D$.AQX___BT0D*(GRZ";L
M__^)-"3H_OG__X/$$.F;_?__@^P,4/]T)!2+1"0@_S"-@PBC__]0BX,(`0``
M_S#HY.+__X/$(.EO_?__C70F`(/L#%")1"04Z+OY__^+1"04B00DZ!_D__^#
MQ!")QNE*_?__C70F`)"+1"0,BP")1"00Z6S^__^0@^P(:@#_="0<Z*+C__^#
MQ!"%P`^$T?[__XE$)`SHOO?__XE$)!")5"04A=(/B+C^__^#P/9J`(/2_U)0
MBTPD&%&)3"0<Z(;A__^#Q`QJ!HV$)/4```!0BTPD&%&)3"0<Z%OB__^#Q!"+
M3"0,@_@&#X7L````@;PD[0````!#04,/A63^__]F@;PD\0```$A%#X54_O__
M:@"+1"04BU0D&(/`SH/2_U)048E,)!SH'N'__X/$#&HHC;PD^P```%>+3"08
M4>CWX?__@\00@_@H#X6,````QH0D&P$```"-@]VB__^#[`A0C8.NHO__5_]T
M)!C_="084%;H@^/__X/$(.EN_O__BT0D#(M0!(72#X2L_?__@^P,4HE4)!SH
M3^'__X/$$(/X`P^&D_W__X/L"(V+GJ+__U&+5"08C40"_%#HV^+__X/$$(M4
M)`R%P`]%5"00B50D$.ED_?__Z'X3``"#[`R-@Z.B__]0Z##V__]55U93Z.WE
M__^!PW]^``"#["QEH10```")1"0<,<"-?"08B?J+LR`!``!EBRX/MD5DB$5E
MC8.LH?__Z!'G__^%P'0)@#@Q#X1$`0``Z&_Q__]EBRZ-@]RB__]J`VH!4%7H
M^^#__X/$$(G%A<!T*8/L!(V#WJ+__U"+10S_,&7_-NBKXO__BT4,@\00BP#V
M0`I`#X5!`0``C8/CHO__:@-J`5!E_S;HMN#__X/$$(G%A<!T*8GZC8-ZH?__
MZ)#F__^%P`^$V````(/L!%"+10S_,&7_-NA7XO__@\00@^P$C8/EHO__:@%0
M9?\VZ`#?__^#Q`R-D_JB__]24&7_-N@MXO__98L&B?K&0&4`C8-QH?__Z#GF
M__^#Q!")@UP!``"%P'0\@^P(:,`!``!0Z*[@__^#Q!"-4`&#^@%V"8/X$0^%
MI@```(M$)!QE*P44````#X7)````@\0L6UY?7<.0@^P,_[-@`0``Z*+W__^#
MQ!")@UP!``"%P'6I@^P,C8.8H___4.@&X/__C;8`````@'@!``^$NO[__^FM
M_O__D.A[Z___A<!T9X/L!%"+50R)1"04_S)E_S;H<N'__XM$)!R)!"3HMM__
M_X/$$.D*____C;8`````@^P(4&7_-NCLW?__@\00Z:O^__]0BX-@`0``_[-<
M`0``_S"-@[RC__]0Z(G?__^-M"8`````9I"+@V`!``"#[`3_,.FL_O__Z$H1
M``"-M"8`````C70F`%=64^B^X___@<-0?```@^P<9:$4````B40D&#'`BWPD
M+%?H>>[__UI9:B]0B<;HG=W__X7`C5`!#T7RB30DZ!W@__^-5"08B<:-@\BA
M___HS.3__X/$$(7`="4/MA"$T@^4P(#Z,`^4P@C0=1.%_W0/@#\`=2*-M"8`
M````C78`BT0D#&4K!10```!U/H/$$%M>7\.-="8`@^P$C8.+HO__:@105NAF
MW?__@\00A<!USXM$)`QE*P44````=0V#Q!")^%M>7^G%Y?__Z&\0``"+!"3#
MBS0DPV:09I!FD&:055=64XG#@>Q\`0``B40D$(U,)"QEH10```")A"1L`0``
M,<"-="8`D(M4@QP/RHD4@8/``8/X$'7OBTPD,(MT)&"-5"0TBVPD9(M$)&B)
M3"0(C8PD-`$``(M<)"R)3"0,ZPJ-M@````")3"0(BPJ)QXM"&(/"!#'(,?")
M[HG],=B+7"0(T<")0C0Y5"0,==F+="00BT0D+(L>BU80BVX(BWX,B50D'(V4
M`IEY@EJ)V(M.!,'`!8G^B6PD%`'"B>B)3"0,,?B)="08(<C!R0(Q^(G?`<*)
MZ(E\)`C!SP(QR"'8BUPD,#'HC;0>F7F"6HG3`<;!PP4!WHG+,?N)V(M<)#0A
MT,'*`C'(C9P=F7F"6HML)#@!PXGPP<`%C8PIF7F"6HML)#P!PXGX,=`A\,'.
M`C'XC;POF7F"6HML)$`!R(G9P<$%`<B)T3'Q(=DQT8V4*IEY@EJ+;"1$`?F)
MQ\''!<'+`@'YB?<QWR'',?>-M"Z9>8):BVPD2`'ZB<_!QP4!^HG'B=C!SP(Q
M^"'(P<D",=B-G"N9>8):BVPD3`'PB=;!Q@4!\(G.B?DQ\2'1,?F-O"^9>8):
MBVPD4`'9B</!PP4!V8G3B?+!RP(QVB'",?*-M"Z9>8):BVPD5`'ZB<_!QP4!
M^HG'B=C!SP(Q^"'(P<D",=B-G"N9>8):BVPD6`'PB=;!Q@4!\(G.B?DQ\2'1
M,?F-O"^9>8):BVPD7`'9B</!PP4!V8G3B?+!RP(QVB'",?*-M"Z9>8):BVPD
M8`'ZB<_!QP4!^HG'B=C!SP(Q^"'(P<D",=B-G"N9>8):BVPD9`'PB=;!Q@4!
M\(G.B?DQ\2'1,?F-O"^9>8):`=F)P\'#!0'9B=.)\L'+`C':(<+!R`(Q\HG%
MB=@!^HG/,>C!QP4AR,')`@'ZBWPD:#'8C;0^F7F"6HG7`?#!QP4!^(GO,<^)
M_HM\)&PAUL'*`C'NC;P[F7F"6HG#`??!PP6+="1P`=^)RS'3C;0UF7F"6HML
M)'0AP\'(`C'+C8PIF7F"6HML)'@!WHG[P<,%`=Z)TS'#(?LQT\'/`HV4*IEY
M@EH!RXGQP<$%`<N)P3'Y(?'!S@(QP0'1B=K!P@4!T8M4)'R-A!"AZ]ENB?HQ
M\C':P<L"`<*)R,'`!0'"BX0D@````(V\!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)
MSXN,)(0```#!SP*-M`ZAZ]ENB=DQ^3'1P<H"`?&)QL'&!0'QB=:+E"2(````
MC9P3H>O9;HGZ,?(QP@':B<O!PP4!VHG#BX0DC````,'+`HV\!Z'KV6Z)\#'8
M,<@!^(G7P<<%`?B)SXN,))````#!SP*-M`ZAZ]ENB=DQ^3'1P<H"`?&)QL'&
M!0'QB=:+E"24````C9P3H>O9;HGZ,?(QP@':B<O!PP4!VHG#BX0DF````,'+
M`HV\!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)SXN,))P```#!SP*-M`ZAZ]ENB=DQ
M^3'1`?&)QL'&!0'QP<H"B=:+E"2@````C9P3H>O9;HGZ,?(QP@':B<O!PP4!
MVHG#BX0DI````,'+`HV\!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)SXN,)*@```#!
MSP*-M`ZAZ]ENB=DQ^3'1P<H"`?&)QL'&!0'QB=:+E"2L````C9P3H>O9;HGZ
M,?(QP@':B<O!PP4!VHG#BX0DL````,'+`HV\!Z'KV6Z)\#'8,<@!^(G7P<<%
M`?B)SXN,)+0```#!SP*-M`ZAZ]ENB=DQ^3'1P<H"`?&)QL'&!0'QB=:+E"2X
M````C9P3H>O9;HGZ,?(QP@':B<O!PP4!VHG#BX0DO````,'+`HV\!Z'KV6Z)
M\#'8,<@!^(G7P<<%`?B)SXN,),````#!SP*-M`ZAZ]ENB=DQ^3'1P<H"`?&)
MQL'&!0'QB=:+E"3$````C9P3H>O9;HGZ,?(QP@':B<O!PP4!VHG#BX0DR```
M`,'+`HG=C9P'H>O9;HGP,>@QR`'8B=/!R0+!PP4!V(GK"<N)WXGK(=<AR\'*
M`@G[B[PDS````(VT/MR\&X^)QP'SP<<%B<X!^XG/(=8)UR''P<@""?Z+O"30
M````C;P]W+P;CXG5`?>)W@G%P<8%(=W!RP(!]XG6(<8)[HNL)-0```"-C"G<
MO!N/B=V)PP'.B?D)Z\'!!2'[`<Z)P2'I"=F+G"38````C9P:W+P;CXGR`<O!
MP@7!SP(!TXGJ"?J)T8GJ(?$A^L'.`@G*BXPDW````(V,"-R\&X^)V`'1P<`%
MB?H!P0GRB?@AVB'PP<L""="+E"3@````C905W+P;CP'"B<C!P`4!PHGP"=B)
MQ8GP(<TAV`GHBZPDY````(V\+]R\&X^)W0'XB=?!QP4!^(G/B=G!SP()_2'Y
M(=4)Z8NL).@```"-M"[<O!N/`?&)QL'*`L'&!0'QB=:)^@GRB=6)^B'%(?()
MZHNL).P```"-G"O<O!N/`=J)R\'#!0':B<.)\,'+`@G8B<6)\"'-(=@)Z(NL
M)/````"-O"_<O!N/B=T!^(G7P<<%`?B)SXG9P<\""?TA^2'5P<H"">F+K"3T
M````C;0NW+P;CP'QB<;!Q@4!\8G6B?H)\HG5B?HAQ2'R">J+K"3X````C9PK
MW+P;CP':B<O!PP4!VHG#B?#!RP()V(G%B?`AS2'8">B+K"3\````C;POW+P;
MCXG=`?B)U\''!0'XB<^)V<'/`@G](?DAU<'*`@GIBZPD``$``(VT+MR\&X\!
M\8G&P<8%`?&)UHGZ"?*)U8GZ(<4A\@GJBZPD!`$``(V<*]R\&X\!VHG+P<,%
M`=J)PXGPP<L"B=V)\PGK(>@ARPG8BYPD"`$``(V<']R\&X\!V(G3P<D"P<,%
M`=B)ZPG+B=^)ZR'7(<O!R@()^XN\)`P!``"-M#[<O!N/B<<!\\''!8G.`?N)
MSR'6"=<AQ\'(`@G^B[PD$`$``(V\/=R\&X\!_HG?P<<%`?Z)UPG'B?V)UR'=
M(<?!RP()[XNL)!0!``"-C"G<O!N/`?F)]\''!0'YB<<)WXG]B<<A]2'?">^+
MK"08`0``C90JW+P;CXML)`@!^HG/P<X"P<<%`?J+O"0<`0``C80XUL%BRHG?
M,?<QS\')`@''B=#!P`4!QXN$)"`!``"-G`/6P6+*B?`QR#'0`=B)^\'#!0'8
MB=.+E"0D`0``P<L"C906UL%BRHG.,=XQ_L'/`@'6B<+!P@4!UHN4)"@!``"-
MC!'6P6+*B=HQ^C'"P<@"`<J)\<'!!0'*B<&+A"0L`0``C80#UL%BRHG[,<LQ
M\P'#B=#!P`4!PXN$)#`!``#!S@*-O`?6P6+*B<@Q\#'0`?B)W\''!0'XB=>+
ME"0T`0``P<\"C901UL%BRHGQ,?DQV<'+`@'1B<+!P@4!T8N4)#@!``"-M!;6
MP6+*B?HQVC'"P<@"`?*)SL'&!0'RB<:+A"0\`0``C80'UL%BRHG?,?<QS\')
M`@''B=#!P`4!QXN$)$`!``"-G`/6P6+*B?`QR#'0`=B)^\'#!0'8B=.+E"1$
M`0``P<L"C906UL%BRHG.,=XQ_L'/`@'6B<+!P@4!UHN4)$@!``"-C!'6P6+*
MB=HQ^C'"P<@"`<J)\<'!!0'*B<&+A"1,`0``C80#UL%BRHG[,<LQ\\'.`@'#
MB=#!P`4!PXN$)%`!``"-O`?6P6+*B<@Q\#'0`?B)W\''!0'XB=>+E"14`0``
MP<\"C901UL%BRHGQ,?DQV<'+`@'1B<+!P@4!T8N4)%@!``"-M!;6P6+*B?HQ
MVC'"`?*)SL'(`L'&!0'RB<:+A"1<`0``C80'UL%BRHG?,?<QS\')`@''B=#!
MP`4!QXN$)&`!``"-G`/6P6+*B?`QR#'0P<H"`=B)^\'#!0'8BYPD9`$``(VT
M'M;!8LJ)RS'3,?O!SP(!\XG&P<8%`?.+M"1H`0``C;0UUL%BRHG=`<Z)T<'%
M!3'Y,<'!R`(!\8MT)!"-+"F+3"0,9@]NQ8ML)!0!RXT,*(M$)!AF#V[;9@]N
MR68/8L.-##AF#V[19@]BRF8/;,$/$0:+1"0<`=")1A"+A"1L`0``92L%%```
M`'4+@<1\`0``6UY?7</H9`0``(UT)@"04^C@UO__@<-R;P``@^P4:F#H6M/_
M_V8/;X.(X?__N?#ATL,QVXE($(E8%,=`&`````#'0%P`````#Q$`@\086\.-
MM"8`````C;0F`````)#HF_/__P4C;P``55=64X/L'(M4)#"+?"0XB40D"(M$
M)#2+6AB-#/T``````TH4C7(<B4H4B?F#TP#!Z1T!V8E*&(M*7(7)='&]0```
M`(UR'"G-.?T/3^\!\3G!#X,G`0``C1PI.=@/@IC3__^-'"B)7"0,B50D,(/L
M!%5048M<)!CH.M/__XM4)$")Z(/$$`-"7(E"7(/X0'0.@\0<6UY?7<.-M@``
M``")T"GOZ/_R__^+1"0,BU0D,(/_/P^.B````(UH0(G#C4)<B7PD.(E$)`R)
M[XML)#B)5"0PZTMFD(M$)`PYPP^"%0$``(E\)`CS#V\#BT0D,(/M0(/#0(/'
M0`\1!O,/;TO0#Q%.$/,/;U/@#Q%6(/,/;UOP#Q%>,.B,\O__@_T_?A<YWG*S
MB7PD"#GS<[LY_G.WZ<;2__]FD(M4)#"+1"0(B>\YQG(J.?!S"XT,.#G.#X*G
MTO__@_\$<T:%_W5ZB7I<@\0<6UY?7<.-M"8`````C0P^.<ASWNF`TO__C70F
M`(T<*(E<)`PYR`^#W/[__SG9#X/4_O__Z6#2__^-="8`BPB)2AR+3#C\B4P^
M_(U.!(/A_"G.*?`!_H/F_(/^!'*=@^;\,=N++!B)+!F#PP0Y\W+SB7I<ZXD/
MM@B(2ASWQP(````/A'3___\/MT0X_F:)1#[^Z67____I_M'__XVT)@````"-
M=@!55U;HC/'__X'&$&T``%.#[!R+7"0TBWPD,(MK&(M+%`_-B>B)S8D$)(G(
M#\W!Z`.);"0$C6L<@^`_C5`!QD0#'("#^C@/CO4```"X0````(U,%0`IT'0B
M,=*H`70,N@$```#&`0`YPG,0Q@01`,9$$0$`@\(".<)R\(G8Z!_Q__]F#^_`
M#Q%#'`\112`/$440#Q%%*/,/?@PDB=AF#]9+5.CZ\/__BP.#[`S!Z!B(!XL#
MP>@0B$<!BP.(9P*+`XA'`P^V0P>(1P0/MT,&B$<%BT,$B&<&BT,$B$<'#[9#
M"XA'"`^W0PJ(1PF+0PB(9PJ+0PB(1PL/MD,/B$<,#[=##HA'#8M##(AG#HM#
M#(A'#P^V0Q.(1Q`/MT,2B$<1BT,0B&<2BT,0B$<34XGSZ-[.__^#Q"Q;7E]=
MPXVV`````+@X````C4P5`"G0@_@$#X*,````C5$$QP$`````@^+\QT0!_```
M```IT0'(@^#\@_@$#X(=____B<&-:/^#X?S![0*)3"0,N00```"#Y0''`@``
M```YP0^#^/[__X7M=!C'0@0`````BT0D#+D(````.<$/@]S^__^+1"0,QP0*
M`````,=$"@0`````@\$(.<%RZNF]_O__C;0F`````)"%P`^$K?[__\8!`*@"
M#X2B_O__,=)FB50!_NF6_O__58GE4^A^TO__@<,0:P``4.C<SO__6EM=PX/L
M#(/$#,,`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N
M86QS.CI005(Z.D)/3U0`97AE`"]P<F]C+R5I+R5S`"X`4$%27U1%35``4$%2
M7U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)
M3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$
M14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-
M4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`#$`;'-E96L@9F%I;&5D`')E860@9F%I;&5D`$Q$7TQ)0E)!4EE?4$%4
M2`!365-414T`+W1M<`!414U01$E2`%1-4`!54T52`%5315).04U%`"4P,G@`
M<&%R+0`E<R5S)7,E<P!P87)L`"YP87(`<VAO<G0@<F5A9``E<R5S8V%C:&4M
M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``
M4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-3D`+64`+2T````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5
M;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F
M9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!
M1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@
M(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'
M24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@
M*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B
M=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@
M*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES
M(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@
M>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S
M:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X
M*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D[
M"GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P
M87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*
M14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E
M8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?
M=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=
M*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER
M(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@
M*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@
M/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2
M(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@
M/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M
M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@
M+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M
M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M
M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@
M>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I
M;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z
M35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@
M("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?
M<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA
M;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P
M<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O
M9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S
M($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?
M<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ
M<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!
M4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#
M2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII
M9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*
M;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*
M;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(
M+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C
M:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%
M<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?
M;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T
M:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D
M8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@
M9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%
M("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*
M;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE
M?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M
M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^
M8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E
M:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I
M;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z
M("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q
M=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:
M25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S
M96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C
M('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!0
M7U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@
M<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP
M87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP
M("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?
M<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO
M<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!
M4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO
M(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L
M<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G
M8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2![
M"B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE
M="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^
M(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ
M<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A
M<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%
M<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?
M<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H
M+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE
M("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE
M('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@
M)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U
M="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D
M;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2![
M"G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI]
M(&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*
M:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC
M(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L
M;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@
M4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII
M;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@
M>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG
M+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK
M*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@
M)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N
M.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F
M:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R
M+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD
M,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF
M("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B
M+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P
M<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H
M)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`]
M(#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH
M)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A
M73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP
M*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O
M9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I
M;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N
M86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F
M:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*
M)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@
M/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C
M86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!
M0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A
M9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'
M24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL
M97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*
M>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA
M;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)
M3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@
M)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H
M(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H
M(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB
M97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF
M:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S
M:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI
M"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]
M($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T
M7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M
M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N
M86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O
M("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA
M;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U
M:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97([
M"G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A
M<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O
M;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T[
M"F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?
M=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*
M?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]4
M35!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I
M9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D
M/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E
M<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D
M<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA
M;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG
M.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP
M86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM
M>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D
M:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H
M*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@
M)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T
M7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L
M(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^
M(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S
M92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M
M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S
M>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S
M+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M
M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D
M9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E
M;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F
M:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*
M8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA
M;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I
M.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@
M*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y
M<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D
M96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B
M(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK
M(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]
M"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB
M4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%
M3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*
M9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!0TA%``!P
M97)L>'-I+F,``````````2-%9XFKS>_^W+J8=E0R$`$;`SL0`0``(0```*!_
M__\L`0``((/__U`!``!`@___;`0``$*#__^@!0``1(/__S@-``!0@___^`L`
M`#"'__]D`0``$(C__]P!``"@B/__*`(``""*___8`@``8(S__U@#``#`C/__
MJ`,```"-___4`P``(([__X@$```PCO__G`0``'"0__^\!0``L)#__^P%``"@
MD?__9`8``*"5__^D!@``$);__\`&``!0EO__Z`8``-"7__^8!P```)C__\0'
M``#PF/__/`@``."?__^H"@``$*+__Y`+``#@HO__0`P``.2B__]4#```\*+_
M_V@,``#PKO__K`P``$"O___0#```4+'__U0-``!/L___I`T``!0`````````
M`7I2``%\"`$;#`0$B`$``"`````<````;'[__X`#````#@A&#@Q*#PMT!'@`
M/QH[*C(D(A````!`````R('__Q@`````````=````%0```#$A?__W`````!!
M#@B%`D$.#(<#00X0A@1!#A2#!4X.,`))#C1!#CA$#CQ!#D!(#C!9"@X40\,.
M$$'&#@Q!QPX(0<4.!$@+=`H.%$/##A!!Q@X,0<<."$'%#@1&"T,.%$/##A!#
MQ@X,0<<."$'%#@0`2````,P````LAO__D`````!!#@B&`D,.#(,#40ZX`50.
MO`%!#L`!2`ZP`6$.N`%"#KP!00[``4@.L`%J"@X,0<,."$'&#@1!"P```*P`
M```8`0``<(;__W8!````00X(A0)!#@R'`T$.$(8$0PX4@P51#M`!<@H.%$'#
M#A!!Q@X,0<<."$'%#@1#"T,.W`%!#N`!2`[0`4D.W`%!#N`!2`[0`6L.W`%!
M#N`!<`[D`4$.Z`%!#NP!00[P`4@.V`%%#MP!00[@`4@.T`%8#MP!00[@`4@.
MT`%##MP!00[@`4@.T`%##MP!00[@`4@.T`%/#MP!00[@`5`.T`$`?````,@!
M``!`A___.`(```!!#@B%`D,.#(<#00X0A@1##A2#!4X.3%<.4$@.0%H.3$,.
M4$P.0`).#DQ+#E!(#D`"9`H.%$'##A!!Q@X,0<<."$'%#@1)"P)D#DQ!#E!2
M#D!4#D1%#DA%#DQ!#E!4#D!9#DA!#DQ!#E!.#D````!,````2`(```")__]:
M`````$$."(8"00X,@P-.#A!-#A1,#AA!#AQ##B!&#AQ'#AA"#AQ!#B!!#B1'
M#BA'#BQ##C!(#@Q!PPX(0<8.!````"@```"8`@``$(G__S8`````00X(@P).
M#A!'#A1,#AA!#AQ)#B!(#@A!PPX$E````,0"```DB?__&0$```!!#@B%`D$.
M#(<#00X0A@1!#A2#!48.E"!*#I1`1PZP0&(.O$!'#L!`00[$0$<.R$!%#LQ`
M10[00$@.L$!;#K1`10ZX0$@.O$!!#L!`2`ZP0$D.O$!$#L!`2`ZP0&@.M$!!
M#KA`00Z\0$$.P$!,#K!`5@H.%$/##A!!Q@X,0<<."$'%#@1)"P`8````7`,`
M`,Q^__\"``````ZP0(,%A0*&!(<#$````'@#``"0B?__!0```````````0``
MC`,``(R)__\U`@```$$."(4"00X,AP-!#A"&!$$.%(,%1@Z4($H.X"$"0`[H
M(4(.["%##O`A2`[@(6T*#A1!PPX00<8.#$''#@A!Q0X$1@M##NPA00[P(48.
M["%!#N@A2P[L(4$.\"%(#N`A<`[H(4$.["%!#O`A2`[@(4L.["%!#O`A2`[@
M(64.["%!#O`A2`[@(4D.["%!#O`A3`[@(5(.Z"%!#NPA1`[P(4$.]"%$#O@A
M10[\(4@.@")(#N`A40[H(40.["%!#O`A2`[@(5<.Z"%$#NPA0@[P(4@.X"$"
M1@[H(4(.["%!#O`A2`[@(50.["%!#O`A2`[@(0```!@```"0!```FGW__P(`
M````#N`A@P6%`H8$AP,L````K`0``*R*__\R`````$$."(8"00X,@P-.#AA&
M#AQ!#B!8#@Q!PPX(0<8.!`!T````W`0``+R*___I`````$$."(8"00X,@P-&
M#HP@1PZ@('4.K"!!#K`@2`Z@(%`.J"!!#JP@10ZP(%`.H"!?#J@@0@ZL($$.
ML"!(#J`@3@ZL($$.L"!(#J`@5@H.#$'##@A!Q@X$1`M##JP@1PZP($@.H"``
M```\````5`4``#2+___\`P```$$."(4"00X,AP-!#A"&!$P.%(,%0PY``[@#
M"@X41\,.$$'&#@Q!QPX(0<4.!$4+&````)0%``#TCO__80````!-#B`"1@H.
M!$4+`"0```"P!0``2(___S0`````00X(@P).#A!'#A1!#AA$#AQ(#B````"L
M````V`4``&"/__]W`0```$$."(4"00X,AP-!#A"&!$$.%(,%1PP#E(`$3@T$
M0P[`@`1>#L2`!$(.R(`$0@[,@`1!#M"`!`)"#L"`!%$.Q(`$1`[(@`1$#LR`
M!$$.T(`$2`[`@`1.#L2`!$4.R(`$00[,@`1!#M"`!$@.P(`$`E@*#A1!PPX0
M0<8.#$''#@A!Q0X$1`MW"@[,@`1'#M"`!$4+0PH.S(`$1P[0@`1%"R@```"(
M!@``,)#__RL`````00X(@P).#A!(#AQ!#B!(#A!)#@A!PPX$````=````+0&
M```TD/__\`````!!#@B%`D$.#(<#00X0A@1!#A2#!4X.0`)""@X40\,.$$'&
M#@Q!QPX(0<4.!$8+0PY(00Y,00Y02`Y`5`H.%$'##A!!Q@X,0<<."$'%#@1+
M"T,.3$$.4&T.5$<.6$$.7$$.8$P.0```:`(``"P'``"LD/__\`8```!!#@B%
M`D$.#(<#00X0A@1!#A2#!5$.P`("XP[,`D$.T`)(#L`"50[,`D$.T`)(#L`"
M0P[,`D4.T`)(#L`"9`[$`D<.R`)!#LP"00[0`DX.P`("1@[,`D$.T`)(#L`"
M>@[,`D$.T`)&#LP"1`[0`ET.S`)'#L@"1`[,`D$.T`)+#M0"1P[8`D,.W`)!
M#N`"2`[(`D4.S`)!#M`"2`[``E@.R`)!#LP"1`[0`D@.P`)>#L0"1@[(`D<.
MS`)(#M`"2`[``EP*#A1#PPX00<8.#$''#@A!Q0X$2PM##LP"1`[0`D@.P`("
M5@[,`D@.T`)(#L`"5@[,`D$.T`)(#L`">0[,`D$.T`)7#L`"2P[(`D$.S`)&
M#M`"3`[``DL.S`)$#M`"2`[``DH.R`)'#LP"30[0`D@.P`("90[(`D$.S`)!
M#M`"2@[4`D0.V`)!#MP"00[@`D@.P`)F#L0"00[(`D$.S`)!#M`"1`[4`D0.
MV`)$#MP"00[@`D@.P`)##L@"10[,`D$.T`)(#L`"2`[,`D0.T`);#L`"2`[,
M`D$.T`)$#M0"1@[8`D<.W`)(#N`"2`[``DP.S`)!#M`"6`[``E\.R`)"#LP"
M1`[0`D@.P`)F#L0"1`[(`D$.S`)%#M`"3`[$`D(.R`)(#LP"10[0`DP.P`)P
M#L0"3P[(`D$.S`)!#M`"3`[$`D(.R`)(#LP"10[0`D@.P`):#L@"00[,`D<.
MT`)$#M0"1`[8`D$.W`)!#N`"2`[``E<.S`)!#M`"3`[``DP.R`)'#LP"20[0
M`D@.P`)<#LP"1P[0`@#D````F`D``#"5__\E`@```$$."(4"00X,AP-!#A"&
M!$$.%(,%3@Y``DH.1$(.2$$.3$$.4$@.0$D.1$<.2$4.3$,.4$L.0%0.1$(.
M2$$.3$,.4$@.0%X.1$$.2$4.3$,.4$@.0$,.1$@.2$$.3$,.4$@.1$<.2$$.
M3$,.4%P.0$T.2$4.3$$.4$@.0&4*#A1!PPX00<8.#$''#@A!Q0X$0@M#"@Y,
M1@Y02`Y`30Y,1PY02PM<#D1!#DA)#DQ##E!4#D!.#DA!#DQ##E!(#D!&"@Y$
M3`Y(0@Y,1PY03@M)"@Y$0@Y(10L`9````(`*``!XEO__T`````!!#@B'`D$.
M#(8#00X0@P1.#BQ1#C!&#BQ!#BA"#BQ!#C!K#B!Y"@X00<,.#$'&#@A!QPX$
M10M##B1(#BA!#BQ!#C!(#B!4"@X00\,.#$'&#@A!QPX$10M$````Z`H``%!W
M__\T`@```$0,`0!)$`4"=0!!$`<"=7Q$$`8"=7@0`P)U=$P/`W5P!@-?`0K!
M#`$`0<-!QD''0<5##`0$00L0````,`L``)B6__\$`````````!````!$"P``
MB);__P0`````````0````%@+``"`EO__^PL```!!#@B%`D$.#(<#00X0A@1!
M#A2#!4@.D`,#Y0L*#A1!PPX00<8.#$''#@A!Q0X$00L````@````G`L``#RB
M__]!`````$$."(,"3@X<0@X@;@X(0<,.!`!D````P`L``&BB__\&`@```$L.
M"(4"00X,AP-!#A"&!$$.%(,%0PXP`FD.-$$..$$./$$.0%(.,$X*#A1!PPX0
M0<8.#$''#@A!Q0X$1PL"Q`H.%$'##A!!Q@X,0<<."$'%#@1("P```!@````H
M#```!';__P(`````#C"#!84"A@2'`P!,````1`P``/2C____`0```$$."(4"
M00X,AP-!#A"&!$P.%(,%0PXP`ID./`*`#D!*#A1!PPX00<8.#$''#@A!Q0X$
M1PXP@P6%`H8$AP,``"````"4#```HZ7__QD`````00X(A0)"#05!@P-3PT'%
M#`0$````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````%`7``#@%@```0````D#```!````%`,``!T```!$!```#``````0
M```-````V$,``!D```#@K0``&P````0````:````Y*T``!P````$````]?[_
M;Q@"```%````%`D```8```#T`@``"@```&($```+````$````!4`````````
M`P```-BN```"````N`$``!0````1````%P```!@.```1````>`T``!(```"@
M````$P````@````>````"````/O__V\!```(^O__;P<`````````````````
M````````````````````````````````````````Z*T`````````````)A``
M`#80``!&$```5A```&80``!V$```AA```)80``"F$```MA```,80``#6$```
MYA```/80```&$0``%A$``"81```V$0``1A$``%81``!F$0``=A$``(81``"6
M$0``IA$``+81``#&$0``UA$``.81``#V$0``!A(``!82```F$@``-A(``$82
M``!6$@``9A(``'82``"&$@``EA(``*82``"V$@``QA(``-82``#F$@``]A(`
M``83```6$P``)A,``#83``!&$P``5A,``&83``!V$P``AA,```````#80P``
M`````````````````````````````````````````````````````,`3````
M```````````0````L```"E!!4BYP;0H`````V%(``$=#0SH@*$%L<&EN92`Q
M,RXR+C%?9VET,C`R,S$P,30I(#$S+C(N,2`R,#(S,3`Q-```+G-H<W1R=&%B
M`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+F=N=2YP<F]P97)T
M>0`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT
M`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M
M:6,`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````````
M```````````````````````````+`````0````(```"T`0``M`$``!<`````
M``````````$`````````$P````<````"````S`$``,P!```D````````````
M```$`````````"8````'`````@```/`!``#P`0``*```````````````!```
M```````Y````]O__;P(````8`@``&`(``-P````%``````````0````$````
M0P````L````"````]`(``/0"```@!@``!@````$````$````$````$L````#
M`````@```!0)```4"0``8@0``````````````0````````!3````"0````(`
M``!X#0``>`T``*`````%``````````0````(````7`````D```!"````&`X`
M`!@.``"X`0``!0```!0````$````"````&4````!````!@`````0````$```
M!P```````````````0````````!@`````0````8````0$```$!```(`#````
M`````````!`````$````:P````$````&````D!,``)`3```8````````````
M```(````"````'0````!````!@```+`3``"P$P``*#``````````````$```
M``````!Z`````0````8```#80P``V$,```<```````````````$`````````
M@`````$````"`````%````!0``!P0``````````````0`````````(@````!
M`````@```'"0``!PD```%`$`````````````!`````````"6`````0````(`
M``"$D0``A)$``+@,``````````````0`````````H`````X````#````X*T`
M`."M```$```````````````$````!````*P````/`````P```.2M``#DK0``
M!```````````````!`````0```"X````!@````,```#HK0``Z*T``/`````&
M``````````0````(````;P````$````#````V*X``-BN```H`0``````````
M```$````!````,$````!`````P````"P````L```%```````````````!```
M``````#'````"`````,````4L```%+```"P```````````````0`````````
MS`````$````P`````````!2P```Q```````````````!`````0````$````#
C``````````````!%L```U0```````````````0``````````
